@@ -6,10 +6,6 @@
 #ifndef __SOUP_H__
 #define __SOUP_H__ 1
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 #define __SOUP_H_INSIDE__
 
 #include "auth/soup-auth.h"
@@ -53,8 +49,4 @@ extern "C" {
 
 #undef __SOUP_H_INSIDE__
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif /* __SOUP_H__ */
